@@ -2,14 +2,12 @@ package Value::Object::DomainLabel;
 
 use warnings;
 use strict;
-use Moo;
-use namespace::clean;
 
 use Value::Object::ValidationUtils;
 
-our $VERSION = '0.07';
+our $VERSION = '0.10';
 
-extends 'Value::Object';
+use parent 'Value::Object';
 
 sub _why_invalid
 {
@@ -35,7 +33,7 @@ Value::Object::DomainLabel - Value object representing 1 label of an Internet do
 
 =head1 VERSION
 
-This document describes Value::Object::DomainLabel version 0.07
+This document describes Value::Object::DomainLabel version 0.10
 
 =head1 SYNOPSIS
 
@@ -81,7 +79,7 @@ C<Value::Object::DomainLabel> requires no configuration files or environment var
 
 =head1 DEPENDENCIES
 
-L<Moo>, L<namespace::clean>
+L<parent>
 
 =head1 INCOMPATIBILITIES
 
@@ -92,7 +90,7 @@ None reported.
 No bugs have been reported.
 
 Please report any bugs or feature requests to
-C<bug-moox-value@rt.cpan.org>, or through the web interface at
+C<bug-value-object@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 AUTHOR
